package com.ruoyi.manage.service.impl;

import java.util.List;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.manage.domain.ResultBeen;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.manage.mapper.LedgerRfidMapper;
import com.ruoyi.manage.domain.LedgerRfid;
import com.ruoyi.manage.service.ILedgerRfidService;
import com.ruoyi.common.core.text.Convert;

/**
 * 轮挡台账Service业务层处理
 *
 * @author wangh
 * @date 2024-01-17
 */
@Service
public class LedgerRfidServiceImpl implements ILedgerRfidService {
    @Autowired
    private LedgerRfidMapper ledgerRfidMapper;

    /**
     * 查询轮挡台账
     *
     * @param objid 轮挡台账主键
     * @return 轮挡台账
     */
    @Override
    public LedgerRfid selectLedgerRfidByObjid(Long objid) {
        return ledgerRfidMapper.selectLedgerRfidByObjid(objid);
    }

    /**
     * 查询轮挡台账列表
     *
     * @param ledgerRfid 轮挡台账
     * @return 轮挡台账
     */
    @Override
    public List<LedgerRfid> selectLedgerRfidList(LedgerRfid ledgerRfid) {
        return ledgerRfidMapper.selectLedgerRfidList(ledgerRfid);
    }

    /**
     * 新增轮挡台账
     *
     * @param ledgerRfid 轮挡台账
     * @return 结果
     */
    @Override
    public int insertLedgerRfid(LedgerRfid ledgerRfid) {
        return ledgerRfidMapper.insertLedgerRfid(ledgerRfid);
    }

    /**
     * 修改轮挡台账
     *
     * @param ledgerRfid 轮挡台账
     * @return 结果
     */
    @Override
    public int updateLedgerRfid(LedgerRfid ledgerRfid) {
        ledgerRfid.setUpdateTime(DateUtils.getNowDate());
        return ledgerRfidMapper.updateLedgerRfid(ledgerRfid);
    }

    /**
     * 批量删除轮挡台账
     *
     * @param objids 需要删除的轮挡台账主键
     * @return 结果
     */
    @Override
    public int deleteLedgerRfidByObjids(String objids) {
        return ledgerRfidMapper.deleteLedgerRfidByObjids(Convert.toStrArray(objids));
    }

    /**
     * 删除轮挡台账信息
     *
     * @param objid 轮挡台账主键
     * @return 结果
     */
    @Override
    public int deleteLedgerRfidByObjid(Long objid) {
        return ledgerRfidMapper.deleteLedgerRfidByObjid(objid);
    }

    @Override
    public int countWasteNumber() {
        return ledgerRfidMapper.countWasteNumber();
    }

    @Override
    public List<ResultBeen> countRfid() {
        return ledgerRfidMapper.countRfid();
    }
}
